#!/usr/bin/env node
'use strict';

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

/** @module TransmuteCLI */

// Process env vars
var MY_ENV = process.env.USE_KUBASH || 'true';

// Vorpal
var vorpal = require('vorpal')();
var vorpalLog = require('vorpal-log');
var vorpalTour = require('vorpal-tour');
vorpal.use(vorpalLog);

// Utils

var _require = require('./utils'),
    writeFile = _require.writeFile;

// Commands


var ls = require('./commands/ls');
var init = require('./commands/init');
var runtest = require('./commands/runtest');
var provision = require('./commands/provision');

// Mixpanel
var Mixpanel = require('mixpanel');
var mixpanel = process.env.MIXPANEL_PROJECT_ID ? Mixpanel.init(process.env.MIXPANEL_PROJECT_ID) : null;

/** transmute k8s  init initializes a cluster with the transmute framework
  * @name transmute k8s init <clustername>
  * @example transmute k8s init myClusterName
  * */
vorpal.command('k8s init <clustername>').description('Initialize k8s cluster').action(function (args, callback) {
  init.k8s(args.clustername);
  callback();
});

/** transmute k8s provision-azure uses azure to provision a k8s cluster
  * @name transmute k8s provision-azure <clustername>
  * @example transmute k8s provision-azure myClusterName --gensshkeys
  * */
vorpal.command('k8s provision-azure <clustername> <group>').description('Provision k8s cluster in Azure').option('--gensshkeys', 'Generate SSH keys').option('--nodes <nodes>', 'How many nodes to create the cluster with').action(function (args, callback) {
  var myNodeCount = 3;
  if (args.options.nodes) {
    myNodeCount = args.options.nodes;
  }
  var GenSSHKeys = false;
  if (args.options.gensshkeys) {
    GenSSHKeys = true;
  }
  provision.aks(args.group, args.clustername, myNodeCount, GenSSHKeys);
  callback();
});

/** transmute k8s provision-minikube uses minikube to provision a k8s cluster
  * @name transmute k8s provision-minikube <clustername>
  * @example transmute k8s provision-minikube myClusterName
  * @param {string} clustername
  * */
vorpal.command('k8s provision-minikube <clustername>').description('Provision k8s cluster').option('--nodes <nodes>', 'How many nodes to create the cluster with').option('--vmdriver <vmdriver>', 'The cluster name to create the cluster with').action(function (args, callback) {
  if (args.options.vmdriver) {
    provision.minikube(args.clustername, args.options.vmdriver);
  } else {
    provision.minikube(args.clustername);
  }
  callback();
});

/** transmute version prints out version info
  * @name transmute version
  * @example transmute version
  * */
vorpal.command('version', 'display version information').action(function () {
  var _ref = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee(args, callback) {
    var version;
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            version = require('../package.json').version;

            vorpal.logger.info('transmute: ' + version);
            callback();

          case 3:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, undefined);
  }));

  return function (_x, _x2) {
    return _ref.apply(this, arguments);
  };
}());

vorpal.delimiter('T$').parse(process.argv).show();